package com.ym.mec.biz.service.impl;

import com.ym.mec.biz.dal.dao.CourseScheduleDao;
import com.ym.mec.biz.dal.dao.OperatingReportCloudDao;
import com.ym.mec.biz.dal.dao.OperatingReportNewDao;
import com.ym.mec.biz.dal.dao.VipGroupCategoryDao;
import com.ym.mec.biz.dal.dto.HumanTypeDto;
import com.ym.mec.biz.dal.dto.OASummaryExpensesDto;
import com.ym.mec.biz.dal.entity.FinancialExpenditure;
import com.ym.mec.biz.dal.entity.OperatingReportNew;
import com.ym.mec.biz.dal.entity.VipGroupCategory;
import com.ym.mec.biz.service.OperatingReportNewService;
import com.ym.mec.common.dal.BaseDAO;
import com.ym.mec.common.service.impl.BaseServiceImpl;
import com.ym.mec.util.collection.MapUtil;
import com.ym.mec.util.date.DateUtil;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

@Service
public class OperatingReportNewServiceImpl extends BaseServiceImpl<Integer, OperatingReportNew>  implements OperatingReportNewService {
	
	@Autowired
	private OperatingReportNewDao operatingReportNewDao;
	@Autowired
	private VipGroupCategoryDao vipGroupCategoryDao;
	@Autowired
	private OperatingReportCloudDao operatingReportCloudDao;
	@Autowired
	private CourseScheduleDao courseScheduleDao;

	@Override
	public BaseDAO<Integer, OperatingReportNew> getDAO() {
		return operatingReportNewDao;
	}

    @Override
    public OperatingReportNewDao getDao() {
        return operatingReportNewDao;
    }


	@Transactional(rollbackFor = Exception.class)
	public void operatingReportMonth1(Date month) {
		String firstDayOfMonth = DateUtil.dateToString(DateUtil.getFirstDayOfMonth(month),DateUtil.ISO_EXPANDED_DATE_FORMAT);
		String lastDayOfMonth = DateUtil.dateToString(DateUtil.getLastDayOfMonth(month),DateUtil.ISO_EXPANDED_DATE_FORMAT);
		String currentMonth = DateUtil.dateToString(DateUtil.getLastDayOfMonth(month),DateUtil.ISO_YEAR_MONTH_FORMAT);
		String currentYear = DateUtil.dateToString(DateUtil.getLastDayOfMonth(month),DateUtil.ISO_YEAR_FORMAT);
		operatingReportNewDao.deleteByMonth(currentMonth);
		List<OperatingReportNew> operatingList = operatingReportNewDao.initOperatingReport(currentMonth);
		//更新团体云教练计费时间()
		operatingReportNewDao.initCloudStartTime(lastDayOfMonth);
		//标记缴费项目为已结算(已排课，并且在上个月有关联的课程)
		operatingReportCloudDao.settlementCalender(currentMonth);
		//标记当月结算的缴费项目(缴费项目结算后缴费、或者进行中加学员的都算当月结算)
		operatingReportCloudDao.settlementCurrentCalender(currentMonth);
		//分部销售收入、销售成本
		List<OperatingReportNew> sellList = operatingReportNewDao.sumSellAmount(currentMonth);
		Map<Integer, OperatingReportNew> collect = sellList.stream().collect(Collectors.groupingBy(OperatingReportNew::getOrganId,Collectors.collectingAndThen(Collectors.toList(),value->value.get(0))));
		//服务收入
		//导入的服务收入  (全部记录为课程收入)
		Map<Integer, BigDecimal> collect24 = MapUtil.convertIntegerMap(operatingReportNewDao.sumImportServerOrderAmount(currentMonth));
		//1、调整student_registration表surplus_course_fee_字段，原有逻辑是用于保存学员已缴费，但是未排课的总乐团课程费用。在课程结束后按课程预计金额分摊到课程实际收入。
		// 现在需要新增逻辑，记录免费团溢出的乐器课费、以及云教练团溢出的课费。用于在课程结束后计算实际课费，涉及到乐团缴费项目、支付回调

		//2、music_group_payment_calender_course_settings表新增字段，用于记录 云教练、乐器溢出的课程费用，在排课时用于计算预计课费、涉及到降费项目创建、报名支付回调

		//3、course_schedule表新增字段 标记课程是否结算经营报表，用于年底确认经营报表收入、或者已结束调整到未开始，涉及到所有的排课、调整、合班、合课逻辑

		//4、课程调整逻辑修改、已结算经营报表的课程不允许调整（需要合业务部门确认）。如果可以调整，需要在course_schedule_student_payment 表新增结算金额，用于记录已结算的金额，在下次结算时去单独计算。

		//5、初始化历史云教练缴费数据，按课程数量和课费总额比例计算，已排课的初始化预计金额、已缴费的初始化实际金额、以及部分排课数据初始化

		//6、云教练按月计算收入，只计算配置金额，溢出的部分分配给课程
		//云教练赠送课程实际收入
//		Map<Integer, BigDecimal> collect1 = MapUtil.convertIntegerMap(operatingReportNewDao.sumCloudCourseAmount(firstDayOfMonth,lastDayOfMonth));
		//亏损的云教练算到当月实际收入
//		Map<Integer, BigDecimal> collect22 = MapUtil.convertIntegerMap(operatingReportNewDao.sumLossCloudAmount(currentMonth));
		//付费课程实际收入
		Map<Integer, BigDecimal> collect2 = MapUtil.convertIntegerMap(operatingReportNewDao.sumCourseAmount(firstDayOfMonth,lastDayOfMonth,currentYear));
		//获取分部学员管理费(每个在读学员80块，算分部成本，总部收入)
		Map<Integer, BigDecimal> studentManagementFeeMap = MapUtil.convertIntegerMap(operatingReportNewDao.sumStudentManagementFee());


		//个人云教练当月收入
		Map<Integer, BigDecimal> collect3 = MapUtil.convertIntegerMap(operatingReportNewDao.sumPersonalCloudAmount(currentMonth,firstDayOfMonth,lastDayOfMonth));
		//团体云教练费用
		Map<Integer, BigDecimal> collect4 = MapUtil.convertIntegerMap(operatingReportNewDao.sumGroupCloudAmount(currentMonth,firstDayOfMonth,lastDayOfMonth));
		//团体云教练当月一次性结转
		Map<Integer, BigDecimal> collect5 = MapUtil.convertIntegerMap(operatingReportNewDao.sumGroupAmount(currentMonth));

		//乐保实收
		Map<Integer, BigDecimal> collect26 = MapUtil.convertIntegerMap(operatingReportNewDao.sumMaintenanceAmount(currentMonth));

		//业务退费
		Map<Integer, BigDecimal> collect6 = MapUtil.convertIntegerMap(operatingReportNewDao.sumRefundAmount(currentMonth));
		//变动费用
		Map<Integer, BigDecimal> collect7 = MapUtil.convertIntegerMap(operatingReportNewDao.sumVariableCosts(currentMonth));
		//固定费用
		Map<Integer, BigDecimal> collect8 = MapUtil.convertIntegerMap(operatingReportNewDao.sumFixedCosts(currentMonth));
		//内部结算
		Map<Integer, BigDecimal> collect18 = MapUtil.convertIntegerMap(operatingReportNewDao.sumInternalSettlement(currentMonth));

		//云教练预收款
		//个人云教练预收款
		Map<Integer, BigDecimal> collect9 = MapUtil.convertIntegerMap(operatingReportNewDao.sumCloudPreAmount(currentMonth,lastDayOfMonth));
		//团体云教练预收款
		Map<Integer, BigDecimal> collect10 = MapUtil.convertIntegerMap(operatingReportNewDao.sumGroupCloudPreAmount(currentMonth,lastDayOfMonth));
		//未生效云教练预收款
		Map<Integer, BigDecimal> collect25 = MapUtil.convertIntegerMap(operatingReportNewDao.sumWaitCloudPreAmount());
		//已排课但是课程未开始的云教练预收
		Map<Integer, BigDecimal> collect27 = MapUtil.convertIntegerMap(operatingReportNewDao.sumNotStartCloudPreAmount());

		//课程预收
		//云教练赠课预收
//		Map<Integer, BigDecimal> collect11 = MapUtil.convertIntegerMap(operatingReportNewDao.sumCloudCoursePreAmount(lastDayOfMonth));
		//云教练赠送，未排课排课资格预收
		//获取categoryId
		VipGroupCategory category = vipGroupCategoryDao.getTheory();
		Map<Integer, BigDecimal> collect20 = MapUtil.convertIntegerMap(operatingReportNewDao.sumActivityUserMapperAmount(category.getId()));
		//付费课程预收
		Map<Integer, BigDecimal> collect12 = MapUtil.convertIntegerMap(operatingReportNewDao.sumCoursePreAmount(lastDayOfMonth));
		//付费团未排乐团课程预收（学员缴费）
		Map<Integer, BigDecimal> collect21 = MapUtil.convertIntegerMap(operatingReportNewDao.sumMusicCourseAmount());
		//排课资格预收
		Map<Integer, BigDecimal> collect23 = MapUtil.convertIntegerMap(operatingReportNewDao.sumSubActivityUserMapperAmount());

		//销售预收
		Map<Integer, BigDecimal> collect13 = MapUtil.convertIntegerMap(operatingReportNewDao.sumSalePreAmount());

		//其他预收
		Map<Integer, BigDecimal> collect14 = MapUtil.convertIntegerMap(operatingReportNewDao.sumOtherPreAmount());

		//预付款
		//房租
		Map<Integer, BigDecimal> collect19 = MapUtil.convertIntegerMap(operatingReportNewDao.sumPrepayments(currentMonth));

		//应收
		//欠费学员总金额
		Map<Integer, BigDecimal> collect15 = MapUtil.convertIntegerMap(operatingReportNewDao.sumArrearsAmount());
		//学校缴费订单待收款金额
		Map<Integer, BigDecimal> collect16 = MapUtil.convertIntegerMap(operatingReportNewDao.sumSchoolAmount());

		//应付（乐器押金）
		List<Map<Integer, BigDecimal>> maps = operatingReportNewDao.sumMusicMargin();
		Map<Integer, BigDecimal> collect17 = MapUtil.convertIntegerMap(maps);

		for (OperatingReportNew operatingReportNew : operatingList) {
			Integer organId = operatingReportNew.getOrganId();
			OperatingReportNew reportNew = collect.get(organId);
			if(Objects.nonNull(reportNew)){
				operatingReportNew.setSaleAmount(reportNew.getSaleAmount());
				operatingReportNew.setSaleCost(reportNew.getSaleCost());
			}
			operatingReportNew.setStudentManagementFee(studentManagementFeeMap.get(organId));
			operatingReportNew.setCourseAmount(getAmount(collect2.get(organId)));
//			operatingReportNew.setCourseAmount(operatingReportNew.getCourseAmount().add(getAmount(collect2.get(organId))));
			operatingReportNew.setCourseAmount(operatingReportNew.getCourseAmount().add(getAmount(collect24.get(organId))));

			operatingReportNew.setCloudAmount(getAmount(collect3.get(organId)));
			operatingReportNew.setCloudAmount(operatingReportNew.getCloudAmount().add(getAmount(collect4.get(organId))));
			operatingReportNew.setCloudAmount(operatingReportNew.getCloudAmount().add(getAmount(collect5.get(organId))));
//			operatingReportNew.setCloudAmount(operatingReportNew.getCloudAmount().add(getAmount(collect22.get(organId))));

			operatingReportNew.setMaintenanceAmount(getAmount(collect26.get(organId)));
			operatingReportNew.setBusinessRefund(getAmount(collect6.get(organId)));

			operatingReportNew.setServiceAmount(operatingReportNew.getCloudAmount().add(operatingReportNew.getCourseAmount()).add(operatingReportNew.getMaintenanceAmount()));
			operatingReportNew.setTotalIncome(operatingReportNew.getSaleAmount().add(operatingReportNew.getServiceAmount()).subtract(operatingReportNew.getBusinessRefund()));

			operatingReportNew.setInternalSettlement(getAmount(collect18.get(organId)));
			operatingReportNew.setVariableCosts(getAmount(collect7.get(organId)));
			//固定费用
			operatingReportNew.setFixedCosts(getAmount(collect8.get(organId)));
			//成本合计
			operatingReportNew.setTotalCost(operatingReportNew.getInternalSettlement().
					add(operatingReportNew.getFixedCosts()).
					add(operatingReportNew.getVariableCosts()).
					add(operatingReportNew.getStudentManagementFee()));

			operatingReportNew.setCloudPrepaidFee(getAmount(collect9.get(organId)).
					add(getAmount(collect10.get(organId))).
					add(getAmount(collect27.get(organId))).
					add(getAmount(collect25.get(organId))));
			operatingReportNew.setCoursePrepaidFee(getAmount(collect12.get(organId)).
					add(getAmount(collect20.get(organId))).add(getAmount(collect21.get(organId))).add(getAmount(collect23.get(organId))));
			operatingReportNew.setSalePrepaidFee(getAmount(collect13.get(organId)));
			operatingReportNew.setOtherPrepaidFee(getAmount(collect14.get(organId)));
			operatingReportNew.setPrepaidFee(operatingReportNew.getCloudPrepaidFee().
					add(operatingReportNew.getSalePrepaidFee()).
					add(operatingReportNew.getOtherPrepaidFee()).
					add(operatingReportNew.getCoursePrepaidFee()));

			operatingReportNew.setReceivables(getAmount(collect15.get(organId)).add(getAmount(collect16.get(organId))));
			operatingReportNew.setPayable(getAmount(collect17.get(organId)));

			operatingReportNew.setPrepayments(getAmount(collect19.get(organId)));

			operatingReportNew.setQuasiDiscretionaryProfit(operatingReportNew.getTotalIncome().subtract(operatingReportNew.getTotalCost()));
		}
		//计算总部经营报表
		OperatingReportNew operatingReportNew = new OperatingReportNew();
		operatingReportNew.setOrganName("总部");
		operatingReportNew.setStudentManagementFee(operatingList.stream().map(e->e.getStudentManagementFee()).reduce(BigDecimal.ZERO,BigDecimal::add));
		OperatingReportNew totalSellAmount = operatingReportNewDao.sumTotalSellAmount(currentMonth);
		operatingReportNew.setSaleAmount(totalSellAmount.getSaleAmount());
		operatingReportNew.setSaleCost(totalSellAmount.getSaleCost());
		operatingReportNewDao.batchInsert(operatingList);
		//将本月乐团课标记为已结算
		courseScheduleDao.makeSettlementReport(currentMonth);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public void operatingReportMonth(Date month) {
		String firstDayOfMonth = DateUtil.dateToString(DateUtil.getFirstDayOfMonth(month),DateUtil.ISO_EXPANDED_DATE_FORMAT);
		String lastDayOfMonth = DateUtil.dateToString(DateUtil.getLastDayOfMonth(month),DateUtil.ISO_EXPANDED_DATE_FORMAT);
		String currentMonth = DateUtil.dateToString(DateUtil.getLastDayOfMonth(month),DateUtil.ISO_YEAR_MONTH_FORMAT);
		String currentYear = DateUtil.dateToString(DateUtil.getLastDayOfMonth(month),DateUtil.ISO_YEAR_FORMAT);
		operatingReportNewDao.deleteByMonth(currentMonth);
		List<OperatingReportNew> operatingList = operatingReportNewDao.initOperatingReport(currentMonth);
		//更新团体云教练计费时间()
		operatingReportNewDao.initCloudStartTime(lastDayOfMonth);
		//标记缴费项目为已结算(已排课，并且在上个月有关联的课程)
		operatingReportCloudDao.settlementCalender(currentMonth);
		//标记当月结算的缴费项目(缴费项目结算后缴费、或者进行中加学员的都算当月结算)
		operatingReportCloudDao.settlementCurrentCalender(currentMonth);
		//分部销售收入、销售成本
		List<OperatingReportNew> sellList = operatingReportNewDao.sumSellAmount(currentMonth);
		Map<Integer, OperatingReportNew> collect = sellList.stream().collect(Collectors.groupingBy(OperatingReportNew::getOrganId,Collectors.collectingAndThen(Collectors.toList(),value->value.get(0))));
		//服务收入
		//导入的服务收入  (全部记录为课程收入)
		Map<Integer, BigDecimal> collect24 = MapUtil.convertIntegerMap(operatingReportNewDao.sumImportServerOrderAmount(currentMonth));
		//付费课程实际收入
		Map<Integer, BigDecimal> collect2 = MapUtil.convertIntegerMap(operatingReportNewDao.sumCourseAmount(firstDayOfMonth,lastDayOfMonth,currentYear));
		//个人云教练当月收入
		Map<Integer, BigDecimal> collect3 = MapUtil.convertIntegerMap(operatingReportNewDao.sumPersonalCloudAmount(currentMonth,firstDayOfMonth,lastDayOfMonth));
		//团体云教练费用
		Map<Integer, BigDecimal> collect4 = MapUtil.convertIntegerMap(operatingReportNewDao.sumGroupCloudAmount(currentMonth,firstDayOfMonth,lastDayOfMonth));
		//团体云教练当月一次性结转
		Map<Integer, BigDecimal> collect5 = MapUtil.convertIntegerMap(operatingReportNewDao.sumGroupAmount(currentMonth));

		//乐保实收
		Map<Integer, BigDecimal> collect26 = MapUtil.convertIntegerMap(operatingReportNewDao.sumMaintenanceAmount(currentMonth));
		//业务退费
		Map<Integer, BigDecimal> collect6 = MapUtil.convertIntegerMap(operatingReportNewDao.sumRefundAmount(currentMonth));
		//变动费用
		Map<Integer, BigDecimal> collect7 = MapUtil.convertIntegerMap(operatingReportNewDao.sumVariableCosts(currentMonth));
		//固定费用
		Map<Integer, BigDecimal> collect8 = MapUtil.convertIntegerMap(operatingReportNewDao.sumFixedCosts(currentMonth));


		//云教练预收款
		//个人云教练预收款
		Map<Integer, BigDecimal> collect9 = MapUtil.convertIntegerMap(operatingReportNewDao.sumCloudPreAmount(currentMonth,lastDayOfMonth));
		//团体云教练预收款
		Map<Integer, BigDecimal> collect10 = MapUtil.convertIntegerMap(operatingReportNewDao.sumGroupCloudPreAmount(currentMonth,lastDayOfMonth));
		//未生效云教练预收款
		Map<Integer, BigDecimal> collect25 = MapUtil.convertIntegerMap(operatingReportNewDao.sumWaitCloudPreAmount());
		//已排课但是课程未开始的云教练预收
		Map<Integer, BigDecimal> collect27 = MapUtil.convertIntegerMap(operatingReportNewDao.sumNotStartCloudPreAmount());
		//获取categoryId
		VipGroupCategory category = vipGroupCategoryDao.getTheory();
		Map<Integer, BigDecimal> collect20 = MapUtil.convertIntegerMap(operatingReportNewDao.sumActivityUserMapperAmount(category.getId()));
		//付费课程预收
		Map<Integer, BigDecimal> collect12 = MapUtil.convertIntegerMap(operatingReportNewDao.sumCoursePreAmount(lastDayOfMonth));
		//付费团未排乐团课程预收（学员缴费）
		Map<Integer, BigDecimal> collect21 = MapUtil.convertIntegerMap(operatingReportNewDao.sumMusicCourseAmount());
		//排课资格预收
		Map<Integer, BigDecimal> collect23 = MapUtil.convertIntegerMap(operatingReportNewDao.sumSubActivityUserMapperAmount());

		//销售预收
		Map<Integer, BigDecimal> collect13 = MapUtil.convertIntegerMap(operatingReportNewDao.sumSalePreAmount());

		//其他预收
		Map<Integer, BigDecimal> collect14 = MapUtil.convertIntegerMap(operatingReportNewDao.sumOtherPreAmount());

		//预付款
		//房租
		Map<Integer, BigDecimal> collect19 = MapUtil.convertIntegerMap(operatingReportNewDao.sumPrepayments(currentMonth));

		//应收
		//欠费学员总金额
		Map<Integer, BigDecimal> collect15 = MapUtil.convertIntegerMap(operatingReportNewDao.sumArrearsAmount());
		//学校缴费订单待收款金额
		Map<Integer, BigDecimal> collect16 = MapUtil.convertIntegerMap(operatingReportNewDao.sumSchoolAmount());

		//应付（乐器押金）
		List<Map<Integer, BigDecimal>> maps = operatingReportNewDao.sumMusicMargin();
		Map<Integer, BigDecimal> collect17 = MapUtil.convertIntegerMap(maps);
		//统计额外的经营报表数据
		List<HumanTypeDto> humanTypeDtos = operatingReportNewDao.sumHumanCost(currentMonth);
		Map<Integer, HumanTypeDto> humanMap = new HashMap<>();
		if(CollectionUtils.isNotEmpty(humanTypeDtos)){
			humanMap = humanTypeDtos.stream().collect(Collectors.groupingBy(e -> e.getOrganId(),Collectors.collectingAndThen(Collectors.toList(),v->v.get(0))));
		}

		for (OperatingReportNew operatingReportNew : operatingList) {
			Integer organId = operatingReportNew.getOrganId();
			OperatingReportNew reportNew = collect.get(organId);
			if(Objects.nonNull(reportNew)){
				operatingReportNew.setSaleAmount(reportNew.getSaleAmount());
				operatingReportNew.setSaleCost(reportNew.getSaleCost());
			}
			HumanTypeDto humanTypeDto = humanMap.get(organId);
			if(Objects.isNull(humanTypeDto)){
				humanTypeDto = new HumanTypeDto();
			}
			//业务退费
			operatingReportNew.setBusinessRefund(getAmount(collect6.get(organId)));
			//服务收入
			operatingReportNew.setServiceAmount(
					getAmount(collect3.get(organId))
					.add(getAmount(collect2.get(organId)))
					.add(getAmount(collect4.get(organId)))
					.add(getAmount(collect5.get(organId)))
					.add(getAmount(collect24.get(organId)))
					.add(getAmount(collect26.get(organId)))
					.add(operatingReportNew.getCourseAmount()));
			//收入合计
			operatingReportNew.setTotalIncome(operatingReportNew.getSaleAmount().add(operatingReportNew.getServiceAmount()).subtract(operatingReportNew.getBusinessRefund()));
			//内部结算
			operatingReportNew.setInternalSettlement(humanTypeDto.getInternalSettlement());
			//变动费用
			operatingReportNew.setVariableCosts(getAmount(collect7.get(organId))
					.add(humanTypeDto.getVariableCost())
					.add(humanTypeDto.getNetworkClassroomCost())
					.add(humanTypeDto.getStudentManagementFeeAdjustment()));
			//固定费用
			operatingReportNew.setFixedCosts(getAmount(collect8.get(organId)).add(humanTypeDto.getFixedCost()));
			//成本合计
			operatingReportNew.setTotalCost(operatingReportNew.getInternalSettlement().
					add(operatingReportNew.getFixedCosts()).
					add(operatingReportNew.getVariableCosts()).
					add(operatingReportNew.getStudentManagementFee()));

			operatingReportNew.setCloudPrepaidFee(getAmount(collect9.get(organId)).
					add(getAmount(collect10.get(organId))).
					add(getAmount(collect27.get(organId))).
					add(getAmount(collect25.get(organId))));
			operatingReportNew.setCoursePrepaidFee(getAmount(collect12.get(organId)).
					add(getAmount(collect20.get(organId))).add(getAmount(collect21.get(organId))).add(getAmount(collect23.get(organId))));
			operatingReportNew.setSalePrepaidFee(getAmount(collect13.get(organId)));
			operatingReportNew.setOtherPrepaidFee(getAmount(collect14.get(organId)));
			operatingReportNew.setPrepaidFee(operatingReportNew.getCloudPrepaidFee().
					add(operatingReportNew.getSalePrepaidFee()).
					add(operatingReportNew.getOtherPrepaidFee()).
					add(operatingReportNew.getCoursePrepaidFee()));

			operatingReportNew.setReceivables(getAmount(collect15.get(organId)).add(getAmount(collect16.get(organId))));
			operatingReportNew.setPayable(getAmount(collect17.get(organId)));

			operatingReportNew.setPrepayments(getAmount(collect19.get(organId)));

			operatingReportNew.setQuasiDiscretionaryProfit(operatingReportNew.getTotalIncome().subtract(operatingReportNew.getTotalCost()));
		}
		//计算总部经营报表
		OperatingReportNew operatingReportNew = new OperatingReportNew();
		operatingReportNew.setOrganName("总部");
		operatingReportNew.setStudentManagementFee(operatingList.stream().map(e->e.getStudentManagementFee()).reduce(BigDecimal.ZERO,BigDecimal::add));
		OperatingReportNew totalSellAmount = operatingReportNewDao.sumTotalSellAmount(currentMonth);
		operatingReportNew.setSaleAmount(totalSellAmount.getSaleAmount());
		operatingReportNew.setSaleCost(totalSellAmount.getSaleCost());
		operatingReportNewDao.batchInsert(operatingList);
		//将本月乐团课标记为已结算
//		courseScheduleDao.makeSettlementReport(currentMonth);
	}

    @Override
    public List<OASummaryExpensesDto> queryOASummaryExpenses(String month) {
		return operatingReportNewDao.queryOASummaryExpenses(month);
    }

	@Override
	public List<FinancialExpenditure> queryOASummaryExpensesDetail(String month) {
		return operatingReportNewDao.queryOASummaryExpensesDetail(month);
	}

	private BigDecimal getAmount(BigDecimal amount){
		if(amount == null){
			amount = BigDecimal.ZERO;
		}
		return amount;
	}
}